@@ -11,45 +11,45 @@ class witterCellRender(gtk.GenericCellRenderer):
 				'Text to be displayed',
 				'Text to be displayed',
 				'',
-				gobject.PARAM_READWRITE
-																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																),
+				gobject.PARAM_READWRITE	),
 			'markup': (gobject.TYPE_STRING,
 				'markup type',
 				'markup type',
 				'',
-				gobject.PARAM_READWRITE
-																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																),
+				gobject.PARAM_READWRITE),
 			'background': (gobject.TYPE_STRING,
 				'Background of the cell',
 				'The background of the cell',
 				'#00FF00',
-				gobject.PARAM_READWRITE
-																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																),
+				gobject.PARAM_READWRITE),
 			'timestamp': (gobject.TYPE_STRING,
 				'timestamp to be displayed',
 				'timestamp to be displayed',
 				'',
-				gobject.PARAM_READWRITE
-																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																),
+				gobject.PARAM_READWRITE),
 			'replyto': (gobject.TYPE_STRING,
 				'reply_to Text to be displayed',
 				'reply_to Text to be displayed',
 				'',
-				gobject.PARAM_READWRITE
-																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																),
+				gobject.PARAM_READWRITE),
+			'source': (gobject.TYPE_STRING,
+				'source Text to be displayed',
+				'source Text to be displayed',
+				'',
+				gobject.PARAM_READWRITE),
 			'font_size': (gobject.TYPE_INT,
 				'font_size',
 				'font_size',
 				0,
 				50,
 				0,
-				gobject.PARAM_READWRITE
-																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																)
+				gobject.PARAM_READWRITE)
 			}
 	rect_height = 0
 	font_size = 16
 
 	def __init__(self):
+		print "renderer init"
 		#gobject.GObject.__init__(self)
 		gtk.GenericCellRenderer.__init__(self)
 
@@ -87,6 +87,7 @@ class witterCellRender(gtk.GenericCellRenderer):
 
 	def on_render(self, window, widget, background_area, cell_area, expose_area, flags):
 		#get a cairo context object
+
 		cairo_context = pangocairo.CairoContext(window.cairo_create())
 
 		x = cell_area.x
@@ -104,16 +105,14 @@ class witterCellRender(gtk.GenericCellRenderer):
 							self.get_cairo_color(color.red),
 							self.get_cairo_color(color.green),
 							self.get_cairo_color(color.blue),
-							1
-																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																)
+							1)
 
 		color = gtk.gdk.color_parse("#0075b5")
 		pat.add_color_stop_rgb(
 							1.0,
 							self.get_cairo_color(color.red),
 							self.get_cairo_color(color.green),
-							self.get_cairo_color(color.blue)
-																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																																)
+							self.get_cairo_color(color.blue))
 
 
 		cairo_context.set_source(pat)
@@ -180,10 +179,10 @@ class witterCellRender(gtk.GenericCellRenderer):
 		cairo_context.select_font_face("Georgia",
                 cairo.FONT_SLANT_NORMAL, cairo.FONT_WEIGHT_BOLD)
 		cairo_context.set_font_size(self.get_property('font_size') - 5)
-		ts_x_bearing, ts_y_bearing, ts_width, ts_height = cairo_context.text_extents(str(self.get_property('timestamp')))[:4]
+		ts_x_bearing, ts_y_bearing, ts_width, ts_height = cairo_context.text_extents("From " + str(self.get_property('source')) + " at " + str(self.get_property('timestamp')))[:4]
 		#position in the bottom right, in set by the width of the timestamp, and a little padding
 		cairo_context.move_to(x + (w - (ts_width + 10)), y + (h - 5))
-		cairo_context.show_text(str(self.get_property('timestamp')))
+		cairo_context.show_text("From " + str(self.get_property('source')) + " at " + str(self.get_property('timestamp')))
 
 #	def render_rect(self, cr, x, y, w, h):
 		#render a rectangle
